==> openwebbeans-2.0.24-source-release.zip: openwebbeans-2.0.24/webbeans-impl/src/test/java/org/apache/webbeans/test/injection/injectionpoint/beans/ConstructorInjectionPointOwner.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.injection.injectionpoint.beans;

import javax.enterprise.context.Dependent;
import javax.enterprise.context.SessionScoped;
import javax.enterprise.inject.spi.InjectionPoint;
import javax.inject.Inject;
import java.io.Serializable;

@Dependent
public class ConstructorInjectionPointOwner extends AbstractInjectionPointOwner
{

    @Inject
    public ConstructorInjectionPointOwner(InjectionPoint ip)
    {
        injectionPoint = ip;
    }

    public ConstructorInjectionPointOwner()
    {

    }

    @SessionScoped
    public static class SomeInnerClassWithInstructorInjectionPoint implements Serializable
    {

        public SomeInnerClassWithInstructorInjectionPoint()
        {
        }
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/injection/injectionpoint/beans/ConstructorInjectionPointOwner.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.injection.injectionpoint.beans;

import jakarta.enterprise.context.Dependent;
import jakarta.enterprise.context.SessionScoped;
import jakarta.enterprise.inject.spi.InjectionPoint;
import jakarta.inject.Inject;
import java.io.Serializable;

@Dependent
public class ConstructorInjectionPointOwner extends AbstractInjectionPointOwner
{

    @Inject
    public ConstructorInjectionPointOwner(InjectionPoint ip)
    {
        injectionPoint = ip;
    }

    public ConstructorInjectionPointOwner()
    {

    }

    @SessionScoped
    public static class SomeInnerClassWithInstructorInjectionPoint implements Serializable
    {

        public SomeInnerClassWithInstructorInjectionPoint()
        {
        }
    }
}
